@@ -2,7 +2,7 @@ import os
 
 import boto3
 from botocore.exceptions import ClientError
-
+from time import sleep
 
 def define_feature_group(
     name,
@@ -42,7 +42,7 @@ def define_feature_group(
     data_lake_bucket_name = (
         os.environ["DATA_LAKE_BUCKET"] if data_lake_bucket is None else data_lake_bucket
     )
-    data_lake_bucket_name = f"{environment_prefix}{data_lake_bucket_name}"
+    data_lake_bucket_name = f"{environment_prefix_name}{data_lake_bucket_name}"
     data_lake_bucket_name = data_lake_bucket_name.replace("_", "-")
 
     region_name = os.environ["AWS_REGION"] if region is None else region
@@ -53,7 +53,7 @@ def define_feature_group(
     )
 
     if s3_key is not None:
-        offline_store_config_object["S3StorageConfig"]= {
+        offline_store_config_object["S3StorageConfig"] = {
             "S3Uri": f"s3://{data_lake_bucket_name}/{s3_key}"
         }
 
@@ -91,6 +91,7 @@ def define_feature_group(
 
     if is_different:
         sagemakerclient.delete_feature_group(FeatureGroupName=feature_group_name)
+        sleep(10)
 
     response = {"Message": "Feature group already exists with the provided definition."}
 
